---
title: Installation & Setup
description: Learn how to install ControlFlow and configure your API keys.
---

<Card title="ControlFlow is under active development" icon="excavator" iconType="duotone">
Pin to a specific version if you want to avoid breaking changes.
However, we recommend frequent updates to get new features and bug fixes.
</Card>

import Installation from '/snippets/installation.mdx';

<Installation />

<Tip>
ControlFlow supports many other LLM providers as well.
See the [LLM documentation](/guides/llms) for more information.
</Tip>

## Next steps

Dive right into the [quickstart](/quickstart), or read the [tutorial](/tutorial) for a step-by-step guide to creating your first ControlFlow workflow.

